pub struct AssetInfo {Show 16 fields
pub immutable: Option<bool>,
pub minimized: Option<bool>,
pub full_hash: FxHashSet<String>,
pub chunk_hash: FxHashSet<String>,
pub content_hash: FxHashSet<String>,
pub source_filename: Option<String>,
pub copied: Option<bool>,
pub development: Option<bool>,
pub hot_module_replacement: Option<bool>,
pub javascript_module: Option<bool>,
pub related: AssetInfoRelated,
pub version: String,
pub css_unused_idents: Option<FxHashSet<String>>,
pub is_over_size_limit: Option<bool>,
pub asset_type: ManifestAssetType,
pub extras: Map<String, Value>,
}Fields
immutable: Option<bool>if the asset can be long term cached forever (contains a hash)
minimized: Option<bool>whether the asset is minimized
full_hash: FxHashSet<String>the value(s) of the full hash used for this asset
chunk_hash: FxHashSet<String>the value(s) of the chunk hash used for this asset
content_hash: FxHashSet<String>the value(s) of the module hash used for this asset the value(s) of the content hash used for this asset
source_filename: Option<String>when asset was created from a source file (potentially transformed), the original filename relative to compilation context
copied: Option<bool>when asset was created from a source file (potentially transformed), it should be flagged as copied
development: Option<bool>size in bytes, only set after asset has been emitted when asset is only used for development and doesn’t count towards user-facing assets
hot_module_replacement: Option<bool>when asset ships data for updating an existing application (HMR)
javascript_module: Option<bool>when asset is javascript and an ESM
related object to other assets, keyed by type of relation (only points from parent to child)
version: Stringthe asset version, emit can be skipped when both filename and version are the same An empty string means no version, it will always emit
css_unused_idents: Option<FxHashSet<String>>unused local idents of the chunk
is_over_size_limit: Option<bool>whether this asset is over the size limit
asset_type: ManifestAssetTypethe plugin that created the asset
extras: Map<String, Value>Webpack: AssetInfo = KnownAssetInfo & Record<string, any> This is a hack to store the additional fields in the rust struct. Related: packages/rspack/src/Compilation.ts
Implementations
Sourceimpl AssetInfo
impl AssetInfo
pub fn with_development(self, v: Option<bool>) -> Self
pub fn with_hot_module_replacement(self, v: Option<bool>) -> Self
pub fn with_content_hashes(self, v: HashSet<String>) -> Self
pub fn with_version(self, v: String) -> Self
pub fn with_asset_type(self, v: ManifestAssetType) -> Self
pub fn set_full_hash(&mut self, v: String)
pub fn set_content_hash(&mut self, v: String)
pub fn set_chunk_hash(&mut self, v: String)
pub fn set_immutable(&mut self, v: Option<bool>)
pub fn set_source_filename(&mut self, v: String)
pub fn set_javascript_module(&mut self, v: bool)
pub fn set_css_unused_idents(&mut self, v: HashSet<String>)
pub fn set_is_over_size_limit(&mut self, v: bool)
pub fn merge_another_asset(&mut self, another: AssetInfo)