pub struct Resolve {Show 23 fields
pub extensions: Option<Vec<String>>,
pub alias: Option<Alias>,
pub prefer_relative: Option<bool>,
pub prefer_absolute: Option<bool>,
pub symlinks: Option<bool>,
pub main_files: Option<Vec<String>>,
pub main_fields: Option<Vec<String>>,
pub condition_names: Option<Vec<String>>,
pub tsconfig: Option<TsconfigOptions>,
pub modules: Option<Vec<String>>,
pub fallback: Option<Alias>,
pub fully_specified: Option<bool>,
pub exports_fields: Option<Vec<Vec<String>>>,
pub extension_alias: Option<Vec<(String, Vec<String>)>>,
pub alias_fields: Option<Vec<Vec<String>>>,
pub roots: Option<Vec<String>>,
pub restrictions: Option<Vec<Restriction>>,
pub imports_fields: Option<Vec<Vec<String>>>,
pub by_dependency: Option<ByDependency>,
pub description_files: Option<Vec<String>>,
pub enforce_extension: Option<bool>,
pub pnp: Option<bool>,
pub builtin_modules: bool,
}Fields
extensions: Option<Vec<String>>Tried detect file with this extension.
alias: Option<Alias>Maps key to value.
The reason for using Vec instead HashMap to keep the order.
prefer_relative: Option<bool>Prefer to resolve request as relative request and fallback to resolving as modules.
prefer_absolute: Option<bool>Prefer absolute paths to resolve.roots when resolving.
symlinks: Option<bool>Whether to resolve the real path when the result is a symlink.
main_files: Option<Vec<String>>Main file in this directory.
main_fields: Option<Vec<String>>Main fields in Description.
condition_names: Option<Vec<String>>Condition names for exports filed. Note that its
type is a HashSet, because the priority is
related to the order in which the export field
fields are written.
tsconfig: Option<TsconfigOptions>the path of tsconfig.
modules: Option<Vec<String>>A list of directories to resolve modules from, can be absolute path or folder name.
Default is ["node_modules"]
fallback: Option<Alias>Same as alias, but only used if default resolving fails
Default is []
fully_specified: Option<bool>Request passed to resolve is already fully specified and
extensions or main files are not resolved for it.
Default is false.
exports_fields: Option<Vec<Vec<String>>>A list of exports fields in descriptions files
Default is [["exports"]].
extension_alias: Option<Vec<(String, Vec<String>)>>A list map ext to another.
Default is []
alias_fields: Option<Vec<Vec<String>>>Specify a field, such as browser, to be parsed according to this specification.
roots: Option<Vec<String>>A list of directories where requests of server-relative URLs (starting with ‘/’) are resolved
restrictions: Option<Vec<Restriction>>A list of resolve restrictions to restrict the paths that a request can be resolved on.
imports_fields: Option<Vec<Vec<String>>>Field names from the description file (usually package.json) which are used to provide internal request of a package (requests starting with # are considered as internal).
by_dependency: Option<ByDependency>Configure resolve options by the type of module request.
description_files: Option<Vec<String>>The JSON files to use for descriptions
Default is [package.json]
enforce_extension: Option<bool>If enforce_extension is set to EnforceExtension::Enabled, resolution will not allow extension-less files. This means require(‘./foo.js’) will resolve, while require(‘./foo’) will not.
pnp: Option<bool>If set, Yarn PnP resolution will be supported.
builtin_modules: boolWhether to parse module.builtinModules or not.
Implementations
Sourceimpl Resolve
impl Resolve
pub fn merge_by_dependency(self, dependency_type: DependencyCategory) -> Self
pub fn merge(self, value: Self) -> Self
pub fn fully_specified(&self, cat: Option<&DependencyCategory>) -> Option<bool>
pub fn prefer_relative(&self, cat: Option<&DependencyCategory>) -> Option<bool>